@@ -179,7 +179,7 @@ def create_qemu_string_from_struct(name :str, info :NewVirtualMachine, current_u
 
 	return create_qemu_string(name, info.namespace, base_hardware, pcie_buses, pcie_root_ports, pcie_slave_buses, pcie_slave_devices)
 
-@app.put("/qemu/machine/{name}/start")
+@app.post("/qemu/machine/{name}/start")
 def start_qemu_machine(name :str, locations :ResourceLocations, current_user: User = Depends(get_current_user)) -> None:
 	"""
 	This endpoint starts a qemu instance using a previously created service file with the given name.
@@ -190,7 +190,7 @@ def start_qemu_machine(name :str, locations :ResourceLocations, current_user: Us
 	else:
 		SysCommand(f"systemctl --user start {name}.service")
 
-@app.put("/qemu/machine/{name}/stop")
+@app.post("/qemu/machine/{name}/stop")
 def stop_qemu_machine(name :str, locations :ResourceLocations, current_user: User = Depends(get_current_user)) -> None:
 	"""
 	This endpoint stops a qemu instance using a previously created service file with the given name.
@@ -199,4 +199,40 @@ def stop_qemu_machine(name :str, locations :ResourceLocations, current_user: Use
 	if locations.run_as == 'root':
 		SysCommand(f"systemctl stop {name}.service")
 	else:
-		SysCommand(f"systemctl --user stop {name}.service")
\ No newline at end of file
+		SysCommand(f"systemctl --user stop {name}.service")
+
+@app.get("/qemu/machine/{name}/status")
+def status_qemu_machine(name :str, current_user: User = Depends(get_current_user)) -> Dict[str, str]:
+	"""
+	This endpoint gets the service status of the machine.
+	If the machine is missing or dead, it will return inactive.
+	"""
+
+	return {'status': str(SysCommand(f"systemctl -o json is-active postgresql {name}.service").decode())}
+
+@app.patch("/qemu/machine/{name}/snapshot")
+def snapshot_qemu_machine(name :str, current_user: User = Depends(get_current_user)) -> None:
+	"""
+	This endpoint enables you to take a snapshot of a machine's current state.
+	If it's running the memory and all devices will be snapshotted using the builtin qemu snapshot tool.
+	If the machine is at rest and the disk volumes are of format qcow2 (or stored on a btrfs/zfs storage) those
+	will be snapshotted manually instead.
+	"""
+
+	raise HTTPException(status_code=501, detail="Not yet implemented")
+
+@app.patch("/qemu/machine/{name}/migrate")
+def migrate_qemu_machine(name :str, current_user: User = Depends(get_current_user)) -> None:
+	"""
+	This endpoint enables you to migrate the machine to a different cluster.
+	"""
+
+	raise HTTPException(status_code=501, detail="Not yet implemented")
+
+@app.post("/qemu/machine/{name}/export")
+def export_qemu_machine(name :str, current_user: User = Depends(get_current_user)) -> None:
+	"""
+	This endpoint enables you to export either the configuration or to do a full export including devices.
+	"""
+
+	raise HTTPException(status_code=501, detail="Not yet implemented")
\ No newline at end of file
